#
# spec file for package texinfo
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# perl modules are not installed in global path
%global __provides_exclude ^(libtool|perl)\\(
Name:           texinfo
Version:        7.0.3
Release:        1.9
Summary:        Tools for creating documentation from texinfo sources
License:        GPL-3.0-or-later
URL:            https://www.gnu.org/software/texinfo/
Source0:        https://ftp.gnu.org/pub/gnu/texinfo/texinfo-%{version}.tar.xz
Source1:        https://ftp.gnu.org/pub/gnu/texinfo/texinfo-%{version}.tar.xz.sig
Source2:        %{name}.keyring
Source42:       %{name}-rpmlintrc
Patch0:         texinfo-zlib.patch
Patch1:         install-info_exitcode.patch
BuildRequires:  automake
BuildRequires:  glibc-locale
BuildRequires:  help2man
BuildRequires:  libbz2-devel
BuildRequires:  libzio-devel
BuildRequires:  ncurses-devel
BuildRequires:  perl
BuildRequires:  perl-Text-Unidecode
BuildRequires:  perl-gettext
BuildRequires:  perl-macros
BuildRequires:  zlib-devel
Requires:       makeinfo = %{version}
Requires:       perl
Requires:       perl-Text-Unidecode
Requires:       perl-gettext
Requires:       texlive-bibtex
Requires:       texlive-latex
Requires:       texlive-makeindex
Requires:       texlive-pdftex
Requires:       texlive-tex
Requires:       texlive-texinfo
Recommends:     texi2html
Recommends:     texi2roff

%description
Texinfo is a documentation system that uses a single source file to
produce both online information and printed output.  Using Texinfo, you
can create a printed document with the normal features of a book,
including chapters, sections, cross-references, and indices.  From the
same Texinfo source file, you can create a menu-driven, online info
file with nodes, menus, cross-references, and indices using the included
makeinfo tool.

%package     -n info
Summary:        A Stand-Alone Terminal-Based Info Browser
Requires:       /usr/bin/gunzip
Requires:       /usr/bin/gzip
Recommends:     info-lang = %{version}

%description -n info
Info is a terminal-based program for reading documentation of computer
programs in the Info format. The GNU Project distributes most of its
on-line manuals in the Info format, so you need a program called "Info
reader" to read the manuals.

%package     -n info-std
Summary:        The info pages of the Info Browser
Supplements:    (info and patterns-base-documentation)
BuildArch:      noarch

%description -n info-std
Info is a terminal-based program for reading documentation of computer
programs in the Info format. The GNU Project distributes most of its
on-line manuals in the Info format, so you need a program called "Info
reader" to read the manuals.

%package     -n makeinfo
Summary:        Translator for converting texinfo documents to info format
# /usr/share/texinfo/Texinfo/Convert/NodeNameNormalization.pm uses Text::Unidecode
Requires:       perl(Text::Unidecode)
%requires_eq    perl
Suggests:       texinfo
Provides:       texinfo:%{_bindir}/makeinfo
Recommends:     info-lang = %{version}
Recommends:     makeinfo-lang = %{version}

%description -n makeinfo
Makeinfo translates Texinfo source documentation to various other
formats, by default Info files suitable for reading online with Emacs
or standalone GNU Info.

%lang_package -n info
%lang_package -n makeinfo

%prep
%setup -q
%autopatch -p1

%build
LANG=en_GB.UTF-8
export LANG
%configure \
	--with-external-Text-Unidecode \
	--enable-perl-xs
%make_build

%install
%make_install
rm -f %{buildroot}%{_libdir}/texinfo/*.a
if cmp  %{buildroot}%{_bindir}/pdftexi2dvi %{buildroot}%{_bindir}/texi2pdf
then
    rm -vf %{buildroot}%{_bindir}/pdftexi2dvi
    ln -sf texi2pdf %{buildroot}%{_bindir}/pdftexi2dvi
fi
if cmp  %{buildroot}%{_mandir}/man1/pdftexi2dvi.1 %{buildroot}%{_mandir}/man1/texi2pdf.1
then
    rm -vf %{buildroot}%{_mandir}/man1/pdftexi2dvi.1
    ln -sf texi2pdf.1%{?ext_man} %{buildroot}%{_mandir}/man1/pdftexi2dvi.1%{?ext_man}
fi

%if 0%{?suse_version} < 1550
mkdir -p %{buildroot}/sbin
mv %{buildroot}%{_bindir}/install-info %{buildroot}/sbin/
ln -sf ../../sbin/install-info %{buildroot}%{_bindir}/install-info
%else
mkdir -p %{buildroot}%{_sbindir}
mv %{buildroot}%{_bindir}/install-info %{buildroot}%{_sbindir}/
ln -sf ../sbin/install-info %{buildroot}%{_bindir}/install-info
%endif

%find_lang %{name} %{name}.lang
%find_lang %{name}_document %{name}_document.lang

%check
LANG=en_GB.UTF-8
export LANG
make %{?_smp_mflags} check

%global trigger_functions %{expand:
-- Check if rpm.execute() as function call is given
if type(rpm.execute) == "function" then
   execute = rpm.execute
else
  function execute(path, ...)
    local pid = posix.fork()
    if not pid then
       error(path .. ": fork failed: " .. posix.errno() .. "\n")
    elseif pid == 0 then
       assert(posix.exec(path, ...))
    else
       posix.wait(pid)
    end
  end
end
--
}

%filetriggerin -n info -p <lua> -- %{_infodir}
%trigger_functions
file = rpm.next_file()
while file do
    if string.match(file, "%%.info%%%{ext_info}$") then
	stat = posix.stat(file)
	if stat then
	    execute("%{_bindir}/install-info", "--info-dir=%{_infodir}", file)
	end
    end
    file = rpm.next_file()
end

%filetriggerun -n info -p <lua> -- %{_infodir}
%trigger_functions
file = rpm.next_file()
while file do
    if string.match(file, "%%.info%%%{ext_info}$") then
	stat = posix.stat(file)
	if not stat then
	    execute("%{_bindir}/install-info", "--quiet", "--delete", "--info-dir=%{_infodir}", file)
	end
    end
    file = rpm.next_file()
end

%files
%defattr(-,root,root,0755)
%license COPYING
%doc ABOUT-NLS AUTHORS NEWS README TODO
%doc doc/texinfo.tex doc/txi-*.tex doc/refcard/*.pdf
%{_bindir}/pod2texi
%{_bindir}/texi2dvi
%{_bindir}/texi2pdf
%{_bindir}/texindex
%{_bindir}/pdftexi2dvi
%{_infodir}/texinfo*%{ext_info}
%{_mandir}/man1/pod2texi.1%{?ext_man}
%{_mandir}/man1/texindex.1%{?ext_man}
%{_mandir}/man1/texi2dvi.1%{?ext_man}
%{_mandir}/man1/texi2pdf.1%{?ext_man}
%{_mandir}/man1/pdftexi2dvi.1%{?ext_man}
%{_mandir}/man5/texinfo.5%{?ext_man}
%attr(644,root,root) %{_datadir}/texinfo/texindex.awk

%files -n makeinfo-lang -f %{name}_document.lang

%files -n makeinfo
%defattr(-,root,root,0755)
%{_bindir}/makeinfo
%{_bindir}/texi2any
%{_infodir}/texi2any_*%{ext_info}
%{_mandir}/man1/makeinfo.1%{?ext_man}
%{_mandir}/man1/texi2any.1%{?ext_man}
%{_libdir}/texinfo
%exclude %{_datadir}/texinfo/texindex.awk
%{_datadir}/texinfo/

%files -n info-lang -f %{name}.lang

%files -n info
%defattr(-,root,root,0755)
%ghost %verify(not mode md5 size mtime) %{_infodir}/dir
%if 0%{?suse_version} < 1550
/sbin/install-info
%else
%{_sbindir}/install-info
%endif
%{_bindir}/install-info
%{_bindir}/info
%{_mandir}/man1/info.1%{?ext_man}
%{_mandir}/man1/install-info.1%{?ext_man}
%{_mandir}/man5/info.5%{?ext_man}

%files -n info-std
%defattr(-,root,root,0755)
%{_infodir}/info-stnd.info%{?ext_info}

%changelog
* Sun Mar 26 2023 Andreas Stieger <andreas.stieger@gmx.de>
- texinfo 7.0.3:
  * texi2any: fix performance regression when Perl binary
    extension (XS) modules are not being used (e.g. with
    TEXINFO_XS=omit)
  * info: further fix of recoding of UTF-8 files to ASCII to avoid
    text disappearing from nodes
  * info: avoid possible freeze at start of a file with
    `-v nodeline=pointers'
* Sat Feb  4 2023 Andreas Stieger <andreas.stieger@gmx.de>
- texinfo 7.0.2:
  * texi2any: do not distribute architecture-dependent files
  * info: further fix of recoding of UTF-8 files to ASCII
  * install-info: build fixes
* Tue Dec 27 2022 Ludwig Nussel <lnussel@suse.com>
- Replace transitional %%usrmerged macro with regular version check (boo#1206798)
* Sun Dec  4 2022 Andreas Stieger <andreas.stieger@gmx.de>
- texinfo 7.0.1:
  * texi2any: avoid multiple crashes on empty @image argument and
    other conditions
  * avoid hang on @ref command inside section command
  * info: fix recoding of UTF-8 files to ASCII when run in C
    locale
  * js: index search fixed for new HTML output
* Tue Nov 15 2022 Dr. Werner Fink <werner@suse.de>
- Update to version 7.0 (7 November 2022)
  * texi2any
  * LaTeX added as an output format, selected with --latex
  * EPUB 3 added as an output format, selected with --epub3
  * reform throughout the code in general
  * thorough review of character encoding issues
  * new customization variables involved with character encoding:
    INPUT_FILE_NAME_ENCODING, OUTPUT_FILE_NAME_ENCODING,
    DOC_ENCODING_FOR_INPUT_FILE_NAME, DOC_ENCODING_FOR_OUTPUT_FILE_NAME,
    MESSAGE_ENCODING and COMMAND_LINE_ENCODING
  * warn if full-text commands (@ref, @footnote, @anchor) appear in @w
  * new variable NO_TOP_NODE_OUTPUT
  * IGNORE_BEFORE_SETFILENAME variable removed.  former effect
    is now always on.
  * HTML output:
  * use manual_name_html as output directory for split HTML instead of
    manual_name or manual_name.html
  * default DOCTYPE declaration changed to plain HTML5 style rather than
    HTML4 DTD reference
  * output only the CSS rules that are needed in an output file
    . remove CSS_LINES variable and add SHOW_BUILTIN_CSS_RULES
  * (custom CSS can still be output using EXTRA_HEAD)
  * use <code> tag for the output of @t and @verb instead of <tt>
  * use <abbr> for @acronym instead of <acronym>
  * link to table of contents from short table of contents only if a
    table of contents is actually output
  * prefix classes from @example arguments with `user-'
  * percent encode URL in @url/@uref, @email, @image and external
    manual file
  * new USE_XML_SYNTAX, HTML_ROOT_ELEMENT_ATTRIBUTES and
    NO_CUSTOM_HTML_ATTRIBUTE variables can be used to output
    valid XHTML
  * systematic addition of classes attribute in HTML elements based on the
    Texinfo @-command names.  renaming of class attributes to avoid
    confusion with @-commands formatting and describe the role in the
    document rather than the formatting style.
  * COPIABLE_ANCHORS renamed to COPIABLE_LINKS
  * do not add a title by default; SHOW_TITLE or NO_TOP_NODE_OUTPUT has
    to be set
  * USE_TITLEPAGE_FOR_TITLE is now true by default
  * L2H variable removed, replaced by HTML_MATH set to `l2h'
  * rename OVERVIEW_LINK_TO_TOC to SHORT_TOC_LINK_TO_TOC
  * rename BEFORE_OVERVIEW to BEFORE_SHORT_TOC_LINE
  * rename AFTER_OVERVIEW to AFTER_SHORT_TOC_LINES
  * remove PRE_ABOUT, AFTER_ABOUT, and add PROGRAM_NAME_IN_ABOUT
  * remove KEEP_TOP_EXTERNAL_REF
  * new variables IGNORE_REF_TO_TOP_NODE_UP, CONVERT_TO_LATEX_IN_MATH,
    HTMLXREF_MODE and HTMLXREF_FILE
  * DocBook output:
  * do not output Top node or text before the first @node or sectioning
    @-command.  NO_TOP_NODE_OUTPUT can be set to false to output Top node
    for now.
  * replace @definfocenlose defined @-commands by the argument as-is
    to be more consistent with printed output
  * HTML/DocBook output:
  * USE_NUMERIC_ENTITY changed to mean to use numeric entities instead
    of named entities.  former effect is now always on.
  * ENABLE_ENCODING_USE_ENTITY variable removed.  former effect is now
    always off.
  * Info output
  * quote problematic node names (with :, comma...) by default
  * new customization variable ASCII_PUNCTUATION to use plain ASCII
    characters for quotation marks and a few other symbols
  * texinfo.tex
  * `@microtype on' uses microtypography in formatting for pdfTeX and LuaTeX
  * do not ignore @part page immediately following Top node
  * do `@set txicodevaristt' to get slanted typewriter for @var in code,
    `@clear txicodevaristt' to use slanted, variable-width roman font for
    @var everywhere.  flag is @set by default, but we may turn this off
    in the future.
  * new file doc/texinfo-zh.tex for Texinfo documents in Chinese.
    new support file doc/txi-zh.tex for Chinese.  doc/short-sample-zh.texi is
    a sample document.
  * info
  * better support for index entries containing parentheses
  * better support for getting bold text etc. when displaying manpages
  * bug fixed where the first index entry in a file could be ignored
  * M-C-f closes as well as opens footnotes window
  * do not crash if run in Brazilian Portuguese locale
  * Language
  * @deftype* commands use typewriter font in argument list
  * new commands @latex, @iflatex, @ifnotlatex for new LaTeX output format
  * do `@set txidefnamenospace' to omit space after a definition name
  * Other
  * build fixed for glibc 2.34
- Delete patch 13a8894fe2.patch as now part of upstream tar ball
* Wed Aug  3 2022 Dr. Werner Fink <werner@suse.de>
- In case of an update of package info: do never remove existing
  info page from dir file (boo#1201852)
* Fri Jul 29 2022 Dr. Werner Fink <werner@suse.de>
- Do lua scripting only once for execute() function
* Wed Jul 27 2022 Dr. Werner Fink <werner@suse.de>
- Check for filetrigger lua scriplets if rpm.execute() as function
  call is given and used this
* Tue Apr 26 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Add 13a8894fe2.patch
  * Fixing @headings: Add missing option value 'single'.
    Resolved regression where gpm could not be build.
* Mon Apr 25 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 6.8
  * new command @displaymath for formatting of mathematical notation
  * new command @example takes an argument to specify the language
  * Deprecate commands: @centerchap, @definfoenclose, @refill, @inforef
  * new paper size @bsixpaper
  * texi2any
  * should be faster as Perl XS parser is enabled by default
  * SHOW_MENU customization variable replaced by FORMAT_MENU.
  * only check menu structure if CHECK_NORMAL_MENU_STRUCTURE
    variable is set
  * MathJax support for display of math.
  * JavaScript License Web Labels support
  * Use sectional tables of contents instead of menus by defaut
  * Use section names in links by default
  * CONTENTS_OUTPUT_LOCATION sets location of table of contents
  * Document sections wrapped in <div> elements
  * New variable USE_NODE_DIRECTIONS to use node or section structure
    for node directions
  * copiable anchor links for definitions
  * Don't add an extra period before file extension given as
    an argument to @image if image file is not found
  * info: Support compressed dir files
  * texi2dvi: Stop on first error in input file
  * texinfo.tex:
  * put logical page numbers into PDF's ('page labels')
  * put chapter numbers in the PDF outline
  * new Finnish translation
- Rebased texinfo-zlib.patch
* Mon Feb 21 2022 Dr. Werner Fink <werner@suse.de>
- Split locale text-domain to take care of package info
- The package makeinfo needs both the locale text-domain of info
  and makeinfo
* Fri Feb 18 2022 Dr. Werner Fink <werner@suse.de>
- Do not recommend texinfo-lang in package info anymore (boo#1196156)
- Rename texinfo-lang to makeinfo-lang as package makeinfo
  uses those locale files
* Wed Feb 16 2022 Dr. Werner Fink <werner@suse.de>
- The new package texinfo-lang should not include the binaries
  with its helper files, therefore recreate texinfo package
- Require glibc-locale at build time as otherwise perl falls
  always back to C locale
* Thu Feb 10 2022 Stanislav Brabec <sbrabec@suse.com>
- Split out texinfo-lang package, so info does not refer to
  traslations from texinfo package.
* Thu Sep 30 2021 Dr. Werner Fink <werner@suse.de>
- Move to /usr for UsrMerge (boo#1191099)
* Thu Jan 28 2021 Thorsten Kukuk <kukuk@suse.com>
- Use file requires for gzip to be able to use alternate
  implementations
* Sat Oct 26 2019 Andreas Stieger <andreas.stieger@gmx.de>
- update to 6.7:
  * support of index subentries and sub-subentries with @subentry
  * new commands @seeentry and @seealso in index entries
  * UTF-8 is the default input encoding
  * updates to HTML output of texi2any
  * support of noderename.cnf files has been removed
  * INPUT_PERL_ENCODING, INPUT_ENCODING_NAME, NODE_FILE_EXTENSION,
    NODE_FILENAMES, SHORTEXTN and TOP_NODE_FILE removed as
    customization variables
  * TOP_NODE_FILE_TARGET now contains the extension
  * texi2dvi: unconditionally run in --batch mode, ignore TeX errors
  * info: for a tree search (with M-/), '}' and '{' work as well
    as 'M-}' and 'M-{' to go through the results
* Thu Oct 17 2019 Dr. Werner Fink <werner@suse.de>
- Delete info-dir as not required anymore
* Mon Sep 30 2019 Dr. Werner Fink <werner@suse.de>
- Mark /usr/share/info/dir as %%ghost
* Mon Sep 30 2019 Dr. Werner Fink <werner@suse.de>
- Add a rpmlintrc file to silent useless warnings
* Fri Sep 27 2019 Ludwig Nussel <lnussel@suse.de>
- use filetrigger instead of transfiletrigger
* Fri Sep 27 2019 Dr. Werner Fink <werner@suse.de>
- Temporary disable %%transfiletriggerin/%%transfiletriggerun and
  reintroduce %%post/%%preun with %%install_info/%%install_info_delete
  as libzypp currentyl can not handle first case (boo#1041742)
* Fri Sep 27 2019 Dr. Werner Fink <werner@suse.de>
- Fix patch texinfo-zlib.patch to enable open of compressed info
  files without using a compressor utility (boo#1152105)
* Thu Sep 26 2019 Dr. Werner Fink <werner@suse.de>
- For bug boo#1152105 split of the info pages of package info to be
  able to preinstall gzip before/with first install-info call
* Thu Sep 26 2019 Ludwig Nussel <lnussel@suse.de>
- implement file trigger for installing and removing info pages
  (boo#1152105)
* Wed Aug 28 2019 Dr. Werner Fink <werner@suse.de>
- Move texindex.awk to package texinfo as texindex(1) is part of
  and use this awk script
* Tue Aug 27 2019 Dr. Werner Fink <werner@suse.de>
- Port the texinfo-zlib.patch to new version 6.6 to solve build problems
* Tue Aug 27 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 6.6:
  * Language:
    . new commands @&, @ampchar{}
    . @cropmarks command removed
    . @ctrl is no longer recognised (it was a way to insert literal
    control characters in Info files, but deprecated since the
    time of Texinfo version 2)
    . \usebracesinindexestrue is no longer recommended for using braces in
    index entries, and has been a no-op for some time
  * texi2any
    . extension modules fixed to work with the "thread-safe locales" of
    Perl 5.28 and newer
    . some code changed to stop warnings being given by newer versions of Perl
    . for HTML output, use `id' to define link targets instead of the `name'
    attribute on <a>
    . A native-code implementation of the Texinfo parser has been included
    on an experimental basis, which makes texi2any a lot faster.  Set the
    `TEXINFO_XS_PARSER' environment variable to 1 to use.
    . changes to HTML output:
    . omit colon after node name in menus by default (use
    `MENU_ENTRY_COLON' to add it back)
    . no special CSS for commands like @smallexample
    . new customization variable `SECTION_NAME_IN_TITLE' to use the
    section name as the document <title>
    . use section names instead of node names in generated menus
    . pass on flags set with -D to TeX
    . useless static libraries are not installed
    . the newline after an @insertcopying is not output
    . warning given for @multitable prototypes not in braces
    . @indent and @noindent are not allowed inside the arguments to
    commands where they are not meaningful
    . @quote-arg and @allow-recursion are not recognised (these two used
    to be recognised by makeinfo in macro definitions but were never
    implemented in texinfo.tex)
    . `FIX_TEXINFO' removed as a customization variable
    . do not recognise or warn about obsolete customization variables
  * info
    . debugging output with -x is not diverted to a separate infodebug file
  * Development:
    . switch from Subversion to git
  - https://savannah.gnu.org/git/?group=texinfo
    . automake 1.16
- Drop no longer needed patch:
  * perl-5.28-fixes.patch
* Tue Dec 11 2018 Dominique Leuenberger <dimstar@opensuse.org>
- Update perl-5.28-fixes.patch: Update locale handling for Perl 5.28.
  Perl 5.28 introduced thread-safe locales, where setlocale()
  only affects the locale of the current thread. External code
  like mbrtowc(3) isn't aware of this thread specific locale,
  so we need to explicitly modify the global one instead.
* Thu Nov 22 2018 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase for summaries.
* Tue Oct 30 2018 Dr. Werner Fink <werner@suse.de>
- Add patch perl-5.28-fixes.patch to get build cehck working again
  due broken perl API with perl 5.28 and up (boo#1113945)
* Fri Apr  6 2018 adam.majer@suse.de
- install-info_exitcode.patch: install-info needs to return success
  when it does nothing. We need 0 return value even on failure as
  old packages in SLE-11 and SLE-12 can become uninstallable.
  (bsc#1084997)
* Fri Feb 23 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Fri Jan 26 2018 werner@suse.de
- Do not require bash for package info (boo#1077744)
* Thu Jan  4 2018 mpluskal@suse.com
- Update to version 6.5:
  * info:
    + some bugs fixed:
    a bug where a segfault could happen in the regex search, for
    example when the user entered a single \ as the search string
    + another bug which could make nodes inaccessible in long
    "split" info files
    + a bug where it was not possible to follow a cross-reference
    that was split across more than one line has been fixed
    + do not fall back to a man page if following a cross-reference
    in an info file failed
    + if looking for a file failed, do not convert the name of a
    file to lower-case and look for it again
  * texinfo.tex
    + some faulty definitions for Unicode characters have been
    changed or removed
    + fix indentation in table of contents for entries that are
    split across multiple lines
  * texi2dvi
    + a bug that broke the processing of LaTeX files that did not
    use BibTeX has been fixed
  * texi2any
    + output the encoding declaration of a HTML file earlier so it
    will always occur within first 1024 bytes of file
    + `INLINE_INSERTCOPYING' removed as a customization variable
* Mon Oct  9 2017 werner@suse.de
- Avoid also provide libtool() on texinfo specific perl linkage
* Sat Oct  7 2017 coolo@suse.com
- Drop require on perl(Locale::Messages) as long as we bundle
  perl-libintl-perl (the system one leaves tests failing)
* Sat Oct  7 2017 coolo@suse.com
- Do not provide perl() - the modules are not globally available
  (bsc#1062028)
* Wed Oct  4 2017 dimstar@opensuse.org
- Change perl requires to be exactly the perl version makeinfo was
  built against. We ship a perl loadable module which is hard
  linked to the right version.
* Wed Jul 12 2017 mpluskal@suse.com
- Update to version 6.4:
  * texi2any:
    + for HTML output, place section names before the manual in page
    titles, instead of after them, so it is easier to distinguish pages
    if titles are truncated
    + starting points for ordered lists beginning with 0 or a letter of
    the alphabet are output as attributes on the <ol> tag, as was
    case for Texinfo 4.13 and earlier
    + a bit faster
    + some discrepancies in paragraph formatting between Perl extension
    modules and interpreted Perl modules have been fixed
    + `MACRO_BODY_IGNORES_LEADING_SPACE' customization variable removed,
    and `indent_menu_descriptions' is no longer a possible value for
    `TREE_TRANSFORMATIONS' (as these features did not work as
    documented)
  * info:
    + the `up-line' and `down-line' commands now are like the other
    scrolling commands and are no longer confined to a single node
    (depending on the value of `scroll-behaviour')
    + supplying the --all option with --index-search displays a list
    of matching index entries
    + the style variables like `link-style' can now be set while info
    is running
    + display bug fixed where color could be turned off prematurely
    + several other bugs fixed
    + better portability in test suite
    + do not fall back to showing the dir node if a manual isn't found
    + Do not attempt any kind of conversion of CR LF line endings,
    except on MS-DOS/Windows, when it is done unconditionally.  (This
    replaces a more complicated approach, where this conversion would
    take place if there was a problem finding a node in a file.)  The
    main effect of this change is that Info files with CR LF line
    endings, which would have been produced on MS-DOS/Windows with old
    versions of makeinfo, are only supported on such operating systems.
    + a few of the key bindings under --vi-keys have been changed for
    consistency or to match the documentation
  * texinfo.tex
    + a DVI file with a single empty page can be output again, which
    restores the behavior from Texinfo 6.0 and earlier
- Small packaging clenup:
  * Drop conditions for old releases
  * Run spec-cleaner
  * Run testsuite
* Fri Jan 20 2017 rmaliska@suse.com
- Update to version 6.3:
  * Language:
    + The commands `@setcontentsaftertitlepage' and
    `@setshortcontentsaftertitlepage' have been removed.
    + @-commands are no longer supported within `@errormsg'.
  * texinfo.tex:
    + For a couple of characters (opening and closing braces), use glyphs
    from the standard TeX math fonts instead of using EC fonts which are
    less likely to be installed.
    + Use of user-defined macros in the text of an index entry is more
    reliable when the text contains Texinfo @-commands.
    + @synindex and @syncodeindex have been fixed (broken in the last
    release).
    + Support added for native UTF-8 support with XeTeX and LuaTeX.
    + Support of PDF output with XeTeX improved.
    + You can use a new file doc/texinfo-ja.tex for Texinfo documents in
    Japanese.  doc/short-sample-ja.tex is a sample document.  New
    support file doc/txi-ja.tex for Japanese.
    + texi2any:
    + Fix handling of compiler options when building Perl extension modules.
  * texi2dvi:
    + Can now process files whose absolute paths contain space characters,
    as long a relative path to the file is given.  Better support of
    files with unusual characters in their names.
    + No longer exits prematurely in some circumstances (due to the script
    running under "set -e").
    + Bug fixed which made the `--command' and `--tidy' options
    incompatible.
  * info:
    + Handling of "invalid" value in infokey file fixed.
* Sun Jul 24 2016 p.drouand@gmail.com
- Remove libpth-devel; texinfo doesn't depend on it
* Fri Jul 15 2016 schwab@linux-m68k.org
- Update to 6.1
  * Language:
    . You can now omit the @menu from nodes with other nodes below them in
    the document structure.  If you use "@validatemenus off" near the
    start of a Texinfo file, makeinfo will, where needed, create a menu
    for nodes lacking one given explicitly.
    . An @setfilename line is no longer required at the start of a
    Texinfo file.  (Be aware, though, that some other tools may require
    it, for example Automake.)
    . For processing with TeX, a comma is automatically provided following
    a cross-reference command (such as @xref) when needed to separate
    the page number from following text, so you don't need to add one
    yourself.  See the `Parts of a Cross Reference' node in the manual
    for details.  Behavior when followed by punctuation, as always
    recommended previously, is unchanged.
  * texi2any:
    . Some Perl modules have been rewritten in C to increase speed.
    If Perl extensions can be created, they are used by default;
    otherwise the pure Perl implementations are still used.
    Disable at build time with "configure --disable-perl-xs".  The
    environment variable TEXINFO_XS controls how they are used by
    texi2any.
    . Quotation marks are left out for node names and index entries in
    Info output where they would have been produced by commands such
    as @file or @option.
    . New customization variable INFO_SPECIAL_CHARS_QUOTE to allow use of
    a quoting mechanism for problematic constructs in Info output, for
    example node names containing colons or commas.
    . Commands like @heading are affected by @lowersections and @raisesections
    again, as was the case before Texinfo 5.0.
  * texinfo.tex:
    . You may explicitly specify a sort key for an index entry by preceding
    the text of the entry with the @sortas commmand with the sort key
    desired as a braced argument.   Additionally, you may choose to
    ignore all occurences of the characters \, @, <, and - using new
    flags you can specify with @set: `txiindexbackslashignore',
    `txiindexatsignignore', `txiindexlessthanignore', and
    `txiindexhyphenignore' respectively.
    . Changes to macro handling to more closely match makeinfo.  Ends of
    lines are preserved in an argument to a macro taking a single
    argument.
    . By default, suppress heading line on a page with a chapter on it, to
    avoid having the chapter title repeated.
    . Use a larger font for arguments in a @deffn line and similar.
    . The default indices (cp, ky and so on) now don't get a file opened
    for them unless they are actually used.  This reduces the number of
    files that a run of TeX produces, and also allows for a greater
    number of user-defined indices, because you will not bump into TeX's
    limit of 16 open files at once so soon.
    . For initials in indices that are non-alphanumeric characters (for
    example, backslash, or braces), avoid use of a typewriter font.
    This gives a more consistent appearance.
    . Have a stronger preference for breaking a column in an index before
    a letter heading.
    . Formatting improvements in tables of contents and indices.  Entries
    can extend slightly into the margin instead of being broken across
    two lines, and text is split more evenly across lines.  Reduce
    chance of an orphaned index entry appearing at the top of a column.
    . Support character encodings beyond ASCII for XeTeX and LuaTeX by
    reading file input byte-by-byte.
  * texi2dvi:
    . Support for determining the output files using the `-recorder'
    option to TeX, to help to support more TeX engines.
  * info:
    . New user variables `link-style', `active-link-style', and
    `match-style' enable customization of how cross-references and search
    matches are highlighted.
    . By default only the node pointers are displayed at the top of a node.
    Customize this with the `nodeline' variable.
    . New command M-x tree-search to search all subnodes of a node.
    . Now tries to find referenced manuals in the same directory as the
    current file first, before looking in search path.  Customize this
    with new variable `follow-strategy'.
    . The `mouse' variable is now off by default, in order not to
    interfere with the selection of text in a terminal emulator window.
    . `q' closes a window instead of quitting altogether if there's more
    than one, for example if a help window is open.
    . Several bug fixes, including:
  . one causing the wrong position in a node to be shown when
  following an "anchor" cross-reference
  . one causing a test failure in the t/c-u-m-x-scroll-forward.sh
  test on some platforms
    . Internal changes to reduce memory use and increase speed of
    searches, relative to last release
    . The meaning of the `key-time' variable has changed when its value
    is 0.  This value meant to wait forever in the last release, but now
    it means that the next byte must be available immediately.
  * Documentation:
    . The `info.info' file (and `info.texi' source) is no longer
    distributed with Texinfo.  Now this manual is only in Emacs.
* Thu Oct 15 2015 werner@suse.de
- Package info.info that is revert the previous drop from
  Mon May  6 16:05:29 UTC 2013
* Wed Jul 15 2015 werner@suse.de
- The package texinfo now requires makeinfo of the same version
  to make sure that the correct Texinfo.pm is installed
- libzio is able to handle lz(ma) and xz files as well
* Sat Jul 11 2015 mpluskal@suse.com
- Update to 6.0
  * Language:
    + new commands @sub and @sup, for textual subscripts and
    superscripts.
    + new command @U to insert a Unicode character by code point.
  * texinfo.tex:
    + @url/@uref output in PDF now the same as in DVI, showing the
    url even if the second argument is given, not just as a link
    target. TeX option \urefurlonlylinktrue gives previous
    behavior, of invisible urls.
    + PDF-only \linkcolor and \urlcolor specify colors (default
    black).
  * texi2any:
    + customization variable TOP_NODE_UP_URL now replaces all (dir)
    references; recommended setting for GNU packages is /manual/.
    + new customization variable INDEX_SPECIAL_CHARS_WARNING to
    complain when index entries contain a colon.
    + Docbook output no longer uses <lineannotation> for @r.
    + -D'var val' on the command line works as intended again.
    + --plaintext output can be split.
    + a bit faster.
  * info:
    + invoking as `info foo bar' looks for bar as an index entry
    in manual foo, if not found as a top-level menu item.
    + invoking info with an absolute or explicitly relative file
    name (./foo.info, /tmp/foo.info, etc.) just visits that file.
    + separate `infokey' program has been removed - the .infokey
    file is now read directly by Info.
    + new option --init-file allows overriding ~/.infokey.
    + new variable `highlight-searches' allows highlighting
    results from a search
    + support for mouse scrollwheel, controlled by `mouse'
    variable.
    + new variable `key_time' to control how long to wait for
    byte sequences sent by special keys.
    + new variable `hide-note-references' alters appearance of
    displayed nodes
    + new variable `infopath-no-defaults' allows omitting the
    compile-time Info directory from the Info search path.
    + support input of multibyte characters for searches in
    a UTF-8 locale.
    + if reading an Info file that is known to be in a different
    character encoding to that of the user's environment,
    convert its contents when displayed and substitute
    missing characters
    + new command M-x info-version.
    + the M-x kill-node command has been removed.
    + test suite at build time.
  * texindex:
    + completely new implementation as a literate program using
    Texinfo and (portable) awk (called TexiWeb Jr.).
    + the -o (--output) is not supported, unless we hear of
    someone using it.
    + duplicated sort keys with different display texts result
    in one merged index entry, using the first display text.
    + better sorting and parsing in unusual cases; most
    notably, { and } characters can appear as initials.
  * install-info:
    + handle compressed input file names containing spaces.
    + exit successfully if --remove is given and the dir file
    does not exist.
    + new option --defsection, to be used instead of
    "Miscellaneous" when a section is not present in the Info
    file.
  * texi2dvi:
    + look for the environment variable THUMBPDF_CMD instead of
    THUMBPDF, since thumbpdf itself has used THUMBPDF for options
    since 2000.
    + remove --recode and --recode-from options, since they haven't
    worked as intended for years, so evidently no one needs them.
- refresh texinfo-zlib.patch
* Sat May 16 2015 schwab@linux-m68k.org
- Remove wrong uses of %%install_info
* Fri Apr 24 2015 werner@suse.de
- Add pre requires for install_info for scriptlets
* Sat Mar 28 2015 mpluskal@suse.com
- Add gpg signature
* Fri Feb  6 2015 dimstar@opensuse.org
- Add perl(Locale::Messages) and perl(Text::Unidecode) Requires to
  makeinfo: since the switch to using the external ones, we also
  must ensure to have them present for the user to execute
  makeinfo. And makeinfo can be installed without texinfo (which
  already does require those modules too).
* Fri Feb  6 2015 werner@suse.de
- Avoid including builtin perl-libintl-perl but require the package
- The same for perl-Text-Unidecode
- Move %%install_info_delete from %%postun to %%preun
* Fri Feb  6 2015 dimstar@opensuse.org
- Recommend instead of Require texi2html and texi2roff: they are
  not stricly required to operate texinfo, but can be valuable to
  the users installing it.
* Thu Feb  5 2015 dimstar@opensuse.org
- Completely splitt off texi2html and texi2roff into their own
  package containers. As a consequence, we no longer carry those
  files / patches here (they live in their respective other
  packages): texi2html-1.78.dif, texi2html-5.0.tar.bz2,
  texi2html-5584.patch, texi2html.changes, texi2html.spec,
  texi2roff-2.0-gcc4.patch, texi2roff-2.0.dif, texi2roff-2.0.tar.gz,
  texi2roff.changes, texi2roff.patch.gz and texi2roff.spec.
* Fri Sep 12 2014 werner@suse.de
- Be aware that texinfo is GPL-3.0+
- Require texi2html as well as readded texi2roff to make the build
  system happy
* Wed Aug  6 2014 dmitry_r@opensuse.org
- Update to version 5.2
  * New texinfo commands
  * texi2any is the new generic converter for Texinfo that can
    produce all supported output formats, both those from texi2dvi
    (PDF/DVI) and from makeinfo (Info/HTML/etc.).  texi2any and
    makeinfo are now different names for the same program; there
    are no differences in behavior based on the program name.
  * See more detail at included NEWS file
  * Remove obsolete texinfo-4.12.dif
  * Remove obsolete texi2html-1.78.dif
  * Remove obsolete texi2roff-2.0.dif
  * Remove obsolete texi2roff.patch.bz2
  * Remove obsolete texinfo-4.8-echo.patch
  * Remove obsolete texi2roff-2.0-gcc4.patch
  * Remove obsolete texinfo-4.13a-bug640417.diff
  * Remove obsolete texinfo-4.13a-bug713517.diff
  * Remove obsolete automake-1.12.patch
  * Remove obsolete texinfo-4.13a-bug788574.diff
  * Remove obsolete config-guess-sub-update.patch
  * Rebase texinfo-4.12-zlib.patch to texinfo-zlib.patch
- Merge makeinfo into main package
- Drop not maintained texi2roff
- Drop not maintained texi2html
* Mon May  6 2013 schwab@linux-m68k.org
- Don't package info.info, already part of emacs-info
* Tue Feb 12 2013 schwab@suse.de
- config-guess-sub-update.patch:
  Update config.guess/sub for aarch64
* Tue Nov 20 2012 werner@suse.de
- Use latest CVS version for the last patch
* Mon Nov 19 2012 werner@suse.de
- Be aware that characters of appendix numbering requires a ASCII
  null if used as string (bnc#788574)
* Sat Oct  6 2012 coolo@suse.com
- remove prereq on library names
* Tue Jul 17 2012 werner@suse.de
- Split off makeinfo as separate package to independed from
  TeXLive
* Tue Jul 10 2012 werner@suse.de
- Make it build with latest TeXLive 2012 with new package layout
  + Add missed TeX
  + Also bibtex and makeindex are used by texi2dvi
  + Add some requires to make the texi2* scripts work
* Tue May 29 2012 puzel@suse.com
- fix build with automake-1.12
  - add: automake-1.12.patch
* Wed Feb  8 2012 werner@suse.de
- Work around dully check script of obs
* Thu Dec  1 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Fri Sep  2 2011 werner@suse.de
- Fix UTF-8 range problem of a grep call (bnc#713517)
* Mon May  2 2011 ke@suse.de
- Enhance package description and provide meta info about makeinfo; thus
  you can find this tool more easily with the yast package search..
* Wed Nov 10 2010 meissner@suse.de
- SUSE_ASNEEDED=0 to fix PowerPC build (optimizes
  away the -lz -lbz2 otherwise)
* Wed Sep 22 2010 giecrilj@stegny.2a.pl
- Fix variable types (bnc#640417)
* Mon Jun 28 2010 jengelh@medozas.de
- use %%_smp_mflags
* Sun Dec  6 2009 jengelh@medozas.de
- enable parallel building
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Jul  3 2009 werner@suse.de
- Add provides for texi2html and texi2roff (bnc#469300)
- Update to texi2html 1.82 (2009-01-05)
  * Add new hooks for user functions, for simple @-commands, and at the start and
    end of special regions.
  * Don't use unidecode on unicode characters that are known not to have a good
    transliteration.  This corresponds with characters with an @-command that
    don't have a transliteration, like @exclamdown...
  * handle @alias, @quote*, @guillem*, @textdegree, @allowcodebreaks,
    @fonttextsize, @hyphenation, @click, @clickstyle, @click, @arrow,
    @clicksequence, @geq, @leq, @*headingmarks, @*footingmarks, @smallquotation,
    @ogonek.
    Handle @columnfractions and row prototypes in @multitable better.
  * @documentlanguage is used to set the language each time it is seen (except
    if the language was set on the command line).
  * new option --css-ref, generate reference to a CSS URL.
  * new option --transliterate-file-names, produce file names in ASCII
    transliteration (set in the default case).
  * --no-monolithic is reenabled.
  * @, followed by an argument without brace is now handled. Report from
    Jorge Barros de Abreu.
  * @, is kept with --macro-expand.
  * @math is more compatible with makeinfo/texi2dvi when no external program
    is used. Using tex4ht for html generation should also lead to a correct
    result.
  * Handle right @end block commands followed by something else than a
    spacing character.
  * Remove trailing end of line in @html block.
  * @itemize should produce bullets by default. Report from Reinhold Kainhofer.
  * handle frame files like other files. Report from Reinhold Kainhofer.
- Update to texinfo 4.13a (18 September 2008)
  * A reference card for Texinfo is now available, in doc/refcard.  For
    convenience, preformatted PDF's for letter-size and A4 paper are included.
  * makeinfo:
    . new option --internal-links for HTML output, to write a tsv file
    mapping indexed/toc terms to links, for easy reference from external
    documents.
    . - as an input file name reads standard input.
  * info:
    . support for multibyte encodings such as UTF-8.
    . new option --show-malformed-multibytes, to display malformed multibyte
    sequences.
    . new environment variable INFO_MAN_COMMAND sets the name of man binary
    (use it if you a need to override PATH settings).
  * install-info:
    . bug fix: support names with embedded periods (e.g., config.status) again.
  * Distribution:
    . autoconf 2.63.
* Sun Jun 15 2008 schwab@suse.de
- Update to texinfo 4.12.
  * Language:
    . new commands @clicksequence, @click, and @clickstyle for documenting
    GUI sequences, and @arrow for the default glyph used.
    . new commands @geq{} and @leq{} for the normal >= and <= relations.
  * install-info:
    . lzma compression supported.
    . Much work towards compatibility with Debian's independent
    implementation.  Changes in behavior:
  - new entries are formatted to start at column 34 by default.
  - existing entries are replaced by default.
  - new sections are alphabetized among existing sections.
  - if an entry being removed is the last one in a section, the
  section is also removed.
    . Also many new options:
  - -section REGEX TITLE.
  - -no-indent: disable formatting of new entries.
  - -menuentry, --name: specify left-hand side of an entry.
  - -dry-run: alias for --test.
  - -regex REGEX: renamed from --section regex, adds to all sections
  matching REGEX by default.
  - -add-once: add only to first specified or matching section.
  - -align COL: start description at column COL.
  - -calign COL: start continuation lines in description at COL.
  - -max-width COL: wrap the description at COL.
    . New section in the Texinfo manual describing all this.
  * Info:
    Our goal with these changes to the default interface is to make Info
    documents more easily and quickly readable, especially by non-experts.
    . the PageUp and PageDown keys move through the whole document by
    default, instead of just the current node.
    . the h command shows the basic help, and H starts the Info tutorial.
    . the newly-bound x command deletes the current window, e.g., within help.
    . the scroll-step variable is set to 1 by default, for smooth scrolling.
    . the cursor-movement-scrolls-p variable is set to 1 by default, so
    link searches look through the whole document.
    . regular expression searches are supported, and are the default for
    both regular and incremental searches.
    . the new R command toggles between regexp and literal-string searches.
    . the new variable scroll-last-node controls scrolling at the end of
    the last node; by default, it now simply reports there are no more
    nodes.  To restore the old behavior, set scroll-last-node=Scroll.
    . the precise line number specified in index entries is used if available.
    . --usage=info shows usage for standalone Info.
    . lzma compression supported.
  * Distribution:
    . language support for no removed/renamed to nb, per Norwegian translators.
    . new translation: es.
    . bug fixes in make check (and elsewhere).
    . gettext 0.17, automake 1.10.1, autoconf 2.62.
* Mon Mar 10 2008 werner@suse.de
- Update to texinfo version 4.11 (4.10 was omitted)
  * Language:
  . @documentlanguage now supports an optional country code
    specification after the language code, a la gettext.
  . new command @allowcodebreaks controls breaks at _ and - within @code.
  . new command @frenchspacing controls spacing after sentences.
  . new command @fonttextsize allows changing body text font size to 10pt.
  . new command @textdegree{} produces the normal degrees symbol.
  . new command @thischapternum can be used in TeX headers/footers.
  . new commands for quotes: @quotedblleft @quotedblright
    @quoteleft @quoteright  @quotedblbase @quotesinglbase
    @guillemetleft @guillemetright @guilsinglleft @guilsinglright.
  . new option @set txicodequoteundirected produces an undirected quote
    in code and example output, instead of the regular right quote.
  . new option @set txicodequotebacktick produces a grave accent in
    code and example output, instead of the regular left quote.
  * makeinfo:
  . The @documentlanguage locale is used to translate various document strings.
  . --enable-encoding is now the default, meaning Info and plain text
    output use 8-bit characters given a supported @documentencoding.
  . new option --css-ref=URL for creating a stylesheet <link> in HTML output.
  . new option --transliterate-file-names to use a reduction-to-ASCII
    algorithm for split HTML file names, useful for non-Latin-based languages.
  . @enddots{} outputs three dots instead of four, for consistency with
    texinfo.tex.
  . the Local Variables coding: setting written by --enable-encoding now
    comes at the very end, after the tags table, so that Emacs can find
    it in more cases.
  . @allow-recursion (never documented) is deprecated and produces a warning.
  . @quote-args (never documented) is now the default behavior.
  . centering and such take account of character widths.
  . the --reference-limit option is now a no-op.
  . improvements to XML and Docbook output and the DTD.
  * texinfo.tex:
  . @thissection can now be used in custom headings, and @thischapter
    works reliably even without @set chapternewpage.  Custom headings
    have additional flexibility as well.
  * texi2dvi:
  . pdftexi2dvi is a new wrapper to `texi2dvi --pdf', equal to texi2pdf,
    for the sake of AUC-TeX which prepends `pdf' to the compilation
    command when requested to produce PDF.
  * info:
  . look for info files in the current directory first, by default.
  . when calling man, use -a if no explicit section is found.
  . avoid showing the top(1) man page for nonexistent info files.
  * install-info:
  . new options --section-regex, --remove-exactly, --debug, --test.
  * Distribution:
  . autoconf 2.60, automake 1.10, gettext 0.16.1.
  . gettext support now [external].
  . new translations: hu (Hungarian), rw (Kinyarwandan), vi (Vietnamese).
  . most common sources imported from gnulib.
* Wed Jul 11 2007 werner@suse.de
- Update to texinfo version 4.9
  * GPLv3.
  * texi2dvi:
    . new mode --build=tidy which supports compilation in a separate
    directory, where intermediate files are preserved.
    . new option --build-dir, to specify where the tidy build will take
    place, either locally or globally.  This allows avoiding the clutter
    while preserving auxiliary files.
    . new support for AUC-TeX: texi2dvi (weakly) supports arguments a la
    TeX such as `\nonstopmode\input{file.tex}'.
    . new options --ps and --dvipdf, useful especially for pstricks documents.
    . new option --src-specials, passed to TeX.
    . pdftexi2dvi is a new wrapper to `texi2dvi --pdf', equal to texi2pdf,
    for the sake of AUC-TeX which prepends `pdf' to the compilation
    command when requested to produce PDF.
  * texinfo.tex:
    . Latin1, Latin2, Latin9, and UTF-8 are supported as well as Computer
    Modern can manage.
    . png and jpg images supported in pdf output.
    . new Russian, Serbian, and Ukrainian translations for texinfo.tex:
    txi-ru.tex, txi-sr.tex, txi-uk.tex.
    . section names with \ characters work properly in pdf outlines.
    . have .toc files use @ as the escape character, instead of \.
- Update to texi2html version 1.78
  * Transliterate accented characters in file names. Use Text::Unidecode
    if detected.
  * Handle @frenchspacing, @tie, @indent, @setcontentsaftertitlepage,
    @setshortcontentsaftertitlepage and the obsolete @allow-recursion
    and @quote-arg.
  * With book style the Table of Contents is put where it is set.
  * Use more numeric entities, especially for accented letters.
  * The `examples' directory now contains an init file for Mediawiki output.
    Mediawiki is the GPL'd wiki used by Wikipedia.
  * new init file tex4ht.init. With this init file, httex or htlatex from
    tex4ht is used to format @tex and @math.
  * Init files now have a chance to override all file names, rather than just
    page names.
  * Put the images under a double licence by adding back their original GPL
    licence.
  * If SIMPLE_MENU is true the menu is simply enclosed in a preformatted
    environment.
  * The user can bypass the texi2html functions and provide his own function
    to do things similar that what is done for interfacing with LaTeX2HTML
    or tex4ht.
  * LaTeX2HTML stuff is moved out of texi2html.pl, to T2h_l2h.pm.
  * Add $USER and $DATE variables to override the defaults detected for the
    footer.
  * $TOP_FILE and $TOC_FILE are only set if set by the user. The elements
    file names are in the hash reference $Texi2HTML::THISDOC{'filename'}
    for use in init files.
  * The API for image, normal_text, paragraph and node_file_name has changed.
  * The $ENCODING variable is deprecated, replaced by $ENCODING_NAME
    and $OUT_ENCODING.
  * utf8 is used as default out file encoding. This should allow for utf8
    translations for languages which cannot use @-commands for non ascii
    characters.
  * Use entities for ``, '', ---, -- and quotes used for some formatting
    @-commands if $USE_ISO is set.
  * don't set unset MENU-ENTRY-NAME if it is similar with the NODE-NAME,
    it is useless as it is a construct that shouldn't happen.
  * avoid menu entry and description redundancy in the formatting function
    and not in the main program.
  * accept - in @-command names (compatibility with makeinfo)
  * in user-defined macro arguments a comma in brace is escaped (compatibility
    with makeinfo from texinfo 4.8.90)
  * don't add the section title to the html title when the document isn't split
  * When the file extension is set to the empty string, a trailing `.' will not
    be automatically added to file names.
  * The texi2html script is now created by make and not configure.
  * It is possible to build the translation files from outside of the
    build directory.
  * When configure detects that no Data::Dumper is present, the build scripts
    will simply copy the files instead of breaking.
  * remove handling of quotation second arg, quotation has only one arg.
  * handle nested ifset/ifclear.
  * Improved handling of @sc and @centerchap.
  * More flexible normal_text.
  * style_stack really contains the formatting @-commands.
  * caching of html generated by latex2html reenabled.
  * when not split and no section navigation is output, the about page and
    navigation direction are not output for all the elements.
* Mon Mar 26 2007 rguenther@suse.de
- Add libbz2-devel, ncurses-devel and zlib-devel BuildRequires
- Exchange libzio for libzio-devel BuildRequires
* Mon Feb 19 2007 werner@suse.de
- Avoid array subscript below array bounds (bug #246740)
* Fri Nov 10 2006 werner@suse.de
- Fix buffer overflow in texi2dvi (bug #214920)
* Mon Jul 24 2006 adrian@suse.de
- add libzio as PreReq for info
* Fri Jun 16 2006 werner@suse.de
- Re-enable texi2pdf because now tetex does not install this
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec 19 2005 werner@suse.de
- Add missing sym link to file list
* Thu Oct  6 2005 werner@suse.de
- Use directory for the base of temporary index files (bug #120577)
* Thu Mar 24 2005 uli@suse.de
- fixed to build with GCC4
* Thu Feb 10 2005 werner@suse.de
- Update to next bug fix release 1.76 of texi2html
* Tue Feb  1 2005 werner@suse.de
- Update to bug fix release 1.74 of texi2html
* Thu Jan 27 2005 werner@suse.de
- Fix texi2html to not loop around on broken texi files
- Remove texi2pdf from texinfo file list due already part of
  tetex
* Wed Jan 26 2005 schwab@suse.de
- Reenable strict aliasing.
* Tue Jan 25 2005 werner@suse.de
- Move texi2html version to 1.72
- Update texinfo version to 4.8
* Mon Oct 18 2004 ro@suse.de
- drop no locale support, nb is already there
* Mon Aug  9 2004 werner@suse.de
- Info: check remaining buffer size before printing into echo area
* Fri Jul  2 2004 mfabian@suse.de
- apply makeinfo.patch received from Karl Berry
  <karl@freefriends.org> fixing the problem that makeinfo 4.7
  could not process groff.texinfo anymore. See
  http://lists.gnu.org/archive/html/bug-texinfo/2004-04/msg00026.html
  http://article.gmane.org/gmane.comp.tex.texinfo.bugs/2019/
* Wed Apr 21 2004 werner@suse.de
- Use libzio together with zlib and libbz2 to support bz2 info
  files to avoids pipe()/fork()/execve() calls in install-info.
* Mon Apr 19 2004 werner@suse.de
- Be sure that texi2html find all required tools
* Fri Apr 16 2004 werner@suse.de
- Update to texinfo 4.7
- Use -fno-strict-aliasing
* Sun Mar 14 2004 schwab@suse.de
- Fix uses of snprintf and gzFile.
* Sat Jan 10 2004 adrian@suse.de
- build as user
* Wed Dec 10 2003 werner@suse.de
- Update to texinfo 4.6
* Tue May 20 2003 ro@suse.de
- fix filelist: package files in /usr/share/texinfo
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Sun Mar  9 2003 kukuk@suse.de
- Add zlib to info PreRequires [Bug #24954]
* Tue Feb 11 2003 kukuk@suse.de
- Branch off info sub package
- Add /usr/share/info/dir
* Sat Feb  8 2003 kukuk@suse.de
- Remove PreRequire for gzip, link against zlib instead (patched
  based on version from RH)
* Sat Feb  8 2003 ro@suse.de
- fixed pre/post install scripts
* Fri Feb  7 2003 ro@suse.de
- removed self-prereq again
* Thu Feb  6 2003 aj@suse.de
- Use install_info.
- Update to texinfo 4.5.
* Wed Jan 22 2003 werner@suse.de
- Request gzip before installing (bug #22992)
* Fri Aug 30 2002 werner@suse.de
- Add a warning on missed programs and say what todo (bug #18642)
* Mon Jun 17 2002 schwab@suse.de
- Update to texinfo 4.2.
* Thu Mar  7 2002 schwab@suse.de
- Update to texinfo 4.1.
* Wed Feb 13 2002 schwab@suse.de
- Fix verbose message of texi2dvi.
* Thu Jan 24 2002 okir@suse.de
- fixed tempfile races in texindex (moved all tempfiles
  into a subdirectory of /tmp).
* Wed Jan 16 2002 schwab@suse.de
- Fix bad free in "makeinfo --html".
* Tue Jun 12 2001 schwab@suse.de
- Fix directive inside macro call.
* Thu Apr 12 2001 werner@suse.de
- Use CVS snapshot of texi2html which works on glibc texinfo code
* Thu Apr 12 2001 ro@suse.de
- fixed glossary for texi2html
* Wed Apr 11 2001 werner@suse.de
- Update of texi2html and texi2roff
* Thu Sep 28 2000 werner@suse.de
- Move /usr/bin/install-info to /sbin/install-info and
  set backward compatibility symlink.
* Wed May 31 2000 werner@suse.de
- use rpm macros for common paths
* Mon Feb 28 2000 werner@suse.de
- Fix segmentation fault (close bug #1911)
* Thu Feb  3 2000 werner@suse.de
- Fixed de.po
* Wed Feb  2 2000 werner@suse.de
- Remove Makefile.Linux
- /usr/man -> /usr/share/man
- /usr/info -> /usr/share/info (man pages and main for info program)
- Install info pages of texinfo
* Wed Dec  1 1999 werner@suse.de
- small changes
* Mon Nov 29 1999 ke@suse.de
- update: version 4.0 (#600).
- use BuildRoot.
- install COPYRIGHT, etc.
- don't disable NLS.
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Mon Jan 11 1999 ro@suse.de
- info/terminal.c : TIOCGETC and TIOCGLTC are defined on alpha,
    but we can't access tchars and ltchars strutures,
    so undef both
    use tcgetattr and cfgetospeed to determine output
    speed
* Fri Jul 17 1998 werner@suse.de
- check exit satus of mkdir for temp directories
* Tue Oct 14 1997 ro@suse.de
- update to 3.12
* Tue Oct 14 1997 ro@suse.de
- ready for autobuild
* Fri Oct 10 1997 florian@suse.de
- update to texinfo 3.11
* Sun Jun 22 1997 florian@suse.de
- add debian-changes to support ANSI-cursor movements
- add texi2html 1.51
- add texi2roff 2.0
* Sun Apr 13 1997 florian@suse.de
- cosmetic changes, just done in preparation for glibc
* Thu Jan  2 1997 florian@suse.de
- Update auf neue Version 3.9.
